@@ -1,9 +1,11 @@
-#' Spead a time series wide to allow for a climatology to be calculated.
+#' Spread a time series wide to allow for a climatology to be calculated.
 #'
 #' An internal function that helps to create a wide time series that will
 #' then be used by \code{\link{clim_calc}} within \code{\link{ts2clm}}
 #' to produce a climatology as desired by the user.
 #'
+#' @keywords internal
+#'
 #' @importFrom data.table := %between%
 #'
 #' @param data The data given to this function during the calculations
@@ -16,7 +18,7 @@
 #'
 #' @return The function returns the data (a matrix) in a wide format.
 #'
-#' @author Smit, A. J.
+#' @author Smit, A. J., Villeneuve, A., Schlegel, R. W.
 #'
 clim_spread <- function(data, clim_start, clim_end, windowHalfWidth) {
 
@@ -26,18 +28,38 @@ clim_spread <- function(data, clim_start, clim_end, windowHalfWidth) {
     return(x)
   }
 
+  # testing...
+  # data <- ts_whole
+
   ts_x <- ts_y <- NULL
 
-  ts_clim <- data.table::as.data.table(data)[ts_x %between% c(clim_start, clim_end)]
+  if("hoy" %in% colnames(data)){
+    clim_start_hour <- as.POSIXct(paste0(clim_start," 00:00:00"))
+    clim_end_hour <- as.POSIXct(paste0(clim_end," 23:00:00"))
+    ts_clim <- data[data$ts_x >= clim_start_hour, ]
+    ts_clim <- ts_clim[ts_clim$ts_x <= clim_end_hour, ]
+  } else {
+    ts_clim <- data.table::as.data.table(data)[ts_x %between% c(clim_start, clim_end)]
+  }
   rm(data)
 
-  data.table::setDT(ts_clim)[, ts_x := format(as.Date(ts_x), "%Y") ]
-  ts_spread <- data.table::dcast(ts_clim, doy ~ ts_x, value.var = "ts_y", mean)
+  data.table::setDT(ts_clim)[, ts_x := format(ts_x, "%Y") ]
+  if("hoy" %in% colnames(ts_clim)){
+    ts_spread <- data.table::dcast(ts_clim, hoy ~ ts_x, value.var = "ts_y", mean)
+  } else {
+    ts_spread <- data.table::dcast(ts_clim, doy ~ ts_x, value.var = "ts_y", mean)
+  }
   rm(ts_clim)
 
-  ts_spread_filled <- data.table::data.table((sapply(ts_spread[59:61, ],
-                                                     function(x) .NA2mean(x))))
-  ts_spread[60, ] <- ts_spread_filled[2, ]
+  if("hoy" %in% colnames(ts_spread)){
+    ts_spread_filled <- data.table::data.table((sapply(ts_spread[1416:1441, ],
+                                                       function(x) .NA2mean(x))))
+    ts_spread[1417:1440, ] <- ts_spread_filled[2:25, ]
+  } else {
+    ts_spread_filled <- data.table::data.table((sapply(ts_spread[59:61, ],
+                                                       function(x) .NA2mean(x))))
+    ts_spread[60, ] <- ts_spread_filled[2, ]
+  }
   rm(ts_spread_filled)
 
   begin_pad <- utils::tail(ts_spread, windowHalfWidth)
@@ -48,7 +70,7 @@ clim_spread <- function(data, clim_start, clim_end, windowHalfWidth) {
   ts_spread <- data.table::rbindlist(l)
   rm(l)
 
-  len_yr <- length(lubridate::year(clim_start):lubridate::year(clim_end))
+  len_yr <- length(as.integer(substr(clim_start, 1, 4)):as.integer(substr(clim_end, 1, 4)))
 
   # clim_calc_cpp needs a matrix...
   ts_mat <- as.matrix(ts_spread)[, 2:(len_yr + 1)]
